@@ -1,6 +1,5 @@
 import json
-import re
-from typing import Any, Dict, List, Optional, Union
+from typing import List, Optional, Union
 
 from pydantic import BaseModel, validator
 
@@ -15,7 +14,6 @@ class ElementaryTestResultSchema(BaseModel):
     metrics: Optional[Union[list, dict]]
     result_description: Optional[str] = None
 
-    # pydantic has a bug with Union fields. This is how to support it.
     class Config:
         smart_union = True
 
@@ -27,10 +25,15 @@ class DbtTestResultSchema(BaseModel):
     failed_rows_count: Optional[int] = None
 
 
-class TestMetadataSchema(BaseModel):
+class TestResultDBRowSchema(BaseModel):
+    __test__ = False  # Mark for pytest - The class name starts with "Test" which throws warnings on pytest runs
+
     id: str
+    invocation_id: str = None
+    test_execution_id: str = None
     model_unique_id: Optional[ModelUniqueIdType] = None
     test_unique_id: TestUniqueIdType
+    elementary_unique_id: str
     detected_at: str
     database_name: str = None
     schema_name: str
@@ -50,6 +53,11 @@ class TestMetadataSchema(BaseModel):
     status: str
     test_created_at: Optional[str] = None
     days_diff: float
+    invocations_rank_index: int
+    sample_data: Optional[Union[dict, List]] = None
+
+    class Config:
+        smart_union = True
 
     @validator("detected_at", pre=True)
     def format_detected_at(cls, detected_at):
@@ -67,42 +75,6 @@ class TestMetadataSchema(BaseModel):
     def load_test_results_description(cls, test_results_description):
         return test_results_description.strip() if test_results_description else None
 
-    def get_failed_rows_count(self):
-        failed_rows_count = -1
-        if self.status != "pass" and self.test_results_description:
-            found_rows_number = re.search(r"\d+", self.test_results_description)
-            if found_rows_number:
-                found_rows_number = found_rows_number.group()
-                failed_rows_count = int(found_rows_number)
-        return failed_rows_count
-
-    def get_test_results(
-        self, test_sample_data: Dict[str, Any]
-    ) -> Union[DbtTestResultSchema, ElementaryTestResultSchema]:
-        if self.test_type == "dbt_test":
-            test_results = DbtTestResultSchema(
-                display_name=self.test_name,
-                results_sample=test_sample_data,
-                error_message=self.test_results_description,
-                failed_rows_count=self.get_failed_rows_count(),
-            )
-        else:
-            test_sub_type_display_name = self.test_sub_type.replace("_", " ").title()
-            if self.test_type == "anomaly_detection":
-                if test_sample_data and self.test_sub_type != "dimension":
-                    test_sample_data.sort(key=lambda metric: metric.get("end_time"))
-                test_results = ElementaryTestResultSchema(
-                    display_name=test_sub_type_display_name,
-                    metrics=test_sample_data,
-                    result_description=self.test_results_description,
-                )
-            elif self.test_type == "schema_change":
-                test_results = ElementaryTestResultSchema(
-                    display_name=test_sub_type_display_name.lower(),
-                    result_description=self.test_results_description,
-                )
-        return test_results
-
 
 class TotalsSchema(BaseModel):
     errors: Optional[int] = 0
@@ -152,8 +124,9 @@ class InvocationsSchema(BaseModel):
     description: str
 
 
-class TestInfoSchema(BaseModel):
+class TestMetadataSchema(BaseModel):
     test_unique_id: Optional[str] = None
+    elementary_unique_id: Optional[str] = None
     database_name: Optional[str] = None
     schema_name: Optional[str] = None
     table_name: Optional[str] = None
@@ -176,14 +149,13 @@ class TestInfoSchema(BaseModel):
 
 
 class TestResultSchema(BaseModel):
-    metadata: TestInfoSchema
-    test_results: Union[dict, list]
+    metadata: TestMetadataSchema
+    test_results: Optional[Union[dict, list]] = None
 
-    # pydantic has a bug with Union fields. This is how to support it.
     class Config:
         smart_union = True
 
 
 class TestRunSchema(BaseModel):
-    metadata: TestInfoSchema
+    metadata: TestMetadataSchema
     test_runs: InvocationsSchema
