@@ -8,11 +8,11 @@ class OrderedYaml:
         self.ordered_yaml.preserve_quotes = True
 
     def load(self, file_path: str) -> dict:
-        with open(file_path, "r") as file_obj:
+        with open(file_path, "r", encoding="utf-8") as file_obj:
             return self.ordered_yaml.load(file_obj)
 
     def dump(self, data: dict, file_path: str) -> dict:
-        with open(file_path, "w") as file_obj:
+        with open(file_path, "w", encoding="utf-8") as file_obj:
             return self.ordered_yaml.dump(data, file_obj)
 
     def loads(self, yaml_str: str) -> dict:
